@@ -99,9 +99,9 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         shell: bool = False,
         timeout: Union[int, float] = 3600,
         sleep: float = 0.1,
-        sig_stop: int = signal.SIGTERM,
-        sig_kill: int = SIGKILL,
-        exp_sig: int = None,
+        stop_signal: int = signal.SIGTERM,
+        kill_signal: int = SIGKILL,
+        expected_returncode: Optional[int] = None,
         envvars: Optional[Dict[str, str]] = None,
         stdin: Union[None, int, IO[Any]] = subprocess.PIPE,
         stdout: Union[None, int, IO[Any]] = subprocess.PIPE,
@@ -117,12 +117,13 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         :param int timeout: number of seconds to wait for the process to start
             or stop.
         :param float sleep: how often to check for start/stop condition
-        :param int sig_stop: signal used to stop process run by the executor.
+        :param int stop_signal: signal used to stop process run by the executor.
             default is `signal.SIGTERM`
-        :param int sig_kill: signal used to kill process run by the executor.
+        :param int kill_signal: signal used to kill process run by the executor.
             default is `signal.SIGKILL` (`signal.SIGTERM` on Windows)
-        :param int exp_sig: expected exit code.
-            default is None as it will fall back to the stop signal
+        :param int expected_returncode: expected exit code.
+            default is None which means, Executor will determine a POSIX
+            compatible return code based on signal sent.
         :param dict envvars: Additional environment variables
         :param int stdin: file descriptor for stdin
         :param int stdout: file descriptor for stdout
@@ -155,9 +156,9 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
 
         self._timeout = timeout
         self._sleep = sleep
-        self._sig_stop = sig_stop
-        self._sig_kill = sig_kill
-        self._exp_sig = exp_sig
+        self._stop_signal = stop_signal
+        self._kill_signal = kill_signal
+        self._expected_returncode = expected_returncode
         self._envvars = envvars or {}
 
         self._stdin = stdin
@@ -308,18 +309,20 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         return pids
 
     def stop(
-        self: SimpleExecutorType, sig: int = None, exp_sig: int = None
+        self: SimpleExecutorType,
+        stop_signal: Optional[int] = None,
+        expected_returncode: Optional[int] = None,
     ) -> SimpleExecutorType:
         """
         Stop process running.
 
         Wait 10 seconds for the process to end, then just kill it.
 
-        :param int sig: signal used to stop process run by executor.
+        :param int stop_signal: signal used to stop process run by executor.
             None for default.
-        :param int exp_sig: expected exit code.
-            None for default.
-        :returns: itself
+        :param int expected_returncode: expected exit code.
+            None for default - POSIX compatible behaviour.
+        :returns: self
         :rtype: SimpleExecutor
 
         .. note::
@@ -330,14 +333,11 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         if self.process is None:
             return self
 
-        if sig is None:
-            sig = self._sig_stop
-
-        if exp_sig is None:
-            exp_sig = self._exp_sig
+        if stop_signal is None:
+            stop_signal = self._stop_signal
 
         try:
-            os.killpg(self.process.pid, sig)
+            os.killpg(self.process.pid, stop_signal)
         except OSError as err:
             if err.errno in IGNORED_ERROR_CODES:
                 pass
@@ -358,19 +358,20 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         if self.process is None:
             # the process has already been force killed and cleaned up by the
             # `wait_for` above.
-            return self
-        self._kill_all_kids(sig)
+            return self  # type: ignore[unreachable]
+        self._kill_all_kids(stop_signal)
         exit_code = self.process.wait()
         self._clear_process()
 
-        # Did the process shut down cleanly? A an exit code of `-sig` means
-        # that it has terminated due to signal `sig`, which is intended. So
-        # don't treat that as an error.
-        expected_exit_code = -sig
-        if exp_sig is not None:
-            expected_exit_code = -exp_sig
+        if expected_returncode is None:
+            expected_returncode = self._expected_returncode
+        if expected_returncode is None:
+            # Assume a POSIX approach where sending a SIGNAL means
+            # that the process should exist with -SIGNAL exit code.
+            # https://docs.python.org/3/library/subprocess.html#subprocess.Popen.returncode
+            expected_returncode = -stop_signal
 
-        if exit_code and exit_code != expected_exit_code:
+        if exit_code and exit_code != expected_returncode:
             raise ProcessFinishedWithError(self, exit_code)
 
         return self
@@ -404,7 +405,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         :rtype: SimpleExecutor
         """
         if sig is None:
-            sig = self._sig_kill
+            sig = self._kill_signal
         if self.process and self.running():
             os.killpg(self.process.pid, sig)
             if wait:
@@ -540,7 +541,7 @@ class Executor(SimpleExecutor):
         if exit_code is not None and exit_code != 0:
             # The main process exited with an error. Clean up the children
             # if any.
-            self._kill_all_kids(self._sig_kill)
+            self._kill_all_kids(self._kill_signal)
             self._clear_process()
             raise ProcessExitedWithError(self, exit_code)
 
